library(ggplot2)

# Multiple plot function
#
# ggplot objects can be passed in ..., or to plotlist (as a list of ggplot objects)
# - cols:   Number of columns in layout
# - layout: A matrix specifying the layout. If present, 'cols' is ignored.
#
# If the layout is something like matrix(c(1,2,3,3), nrow=2, byrow=TRUE),
# then plot 1 will go in the upper left, 2 will go in the upper right, and
# 3 will go all the way across the bottom.
#
multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  library(grid)

  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)

  numPlots = length(plots)

  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                    ncol = cols, nrow = ceiling(numPlots/cols))
  }

 if (numPlots==1) {
    print(plots[[1]])

  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))

    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))

      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}

library(ggplot2)
library(RColorBrewer)
library(gtools)


path = path = "C:/mytemp/dropbox/JMCDA/supplementary_material/"#ADD YOUR PERSONAL PATH HERE
num = 1
REFS = c("_CONS_D","_CONS","_IND","_IND_D")
for(re in 1:4){
for(num in 1:4){


setwd(paste(path,"Results/",sep=""))

Results =read.csv(paste("Results_",num,REFS[re],".txt",sep=""),header=FALSE)
Agg_results = matrix(0,dim(Results)[1]*dim(Results)[2],3)
Norm_results = matrix(0,(dim(Results)[1]-1)*dim(Results)[2],3)
for(b in 1:dim(Results)[2]){
for(a in 2:dim(Results)[1]){

Norm_results[a-1+(b-1)*12,2] = Results[a,b]

}}
for(b in 1:dim(Results)[2]){
for(a in 2:dim(Results)[1]){
Norm_results[a-1+(b-1)*12,1] = a-1

}}

for(b in 1:dim(Results)[2]){
for(a in 2:dim(Results)[1]){
Norm_results[a-1+(b-1)*12,3] = b

}}


for(a in 2:dim(Results)[1]){
for(b in 1:dim(Results)[2]){
Norm_results[a-1+(b-1)*12,2] = Norm_results[a-1+(b-1)*12,2]/sum(Results[1])

}}

d2 = data.frame(Norm_results)
Agg_results = matrix(0,dim(Results)[1]*dim(Results)[2],3)
for(b in 1:dim(Results)[2]){
for(a in 2:dim(Results)[1]){

Agg_results[a+(b-1)*13,2] = Agg_results[a-1+(b-1)*13,2]+Results[a,b]

}}
for(b in 1:dim(Results)[2]){
for(a in 1:dim(Results)[1]){
Agg_results[a+(b-1)*13,1] = b

}}


for(a in 1:dim(Results)[1]){
for(b in 1:dim(Results)[2]){
Agg_results[a+(b-1)*13,2] = Agg_results[a+(b-1)*13,2]/sum(Results[1])

}}

d1 = data.frame(Agg_results)

for(b in 1:length(d1$X1)){
if(nchar(toString(d1$X1[b]))==1){
c1 = "A "} else {
c1 = "A"}

d1$X1[b] = paste(c1,toString(d1$X1[b]),sep="")
}

for(b in 1:length(d1$X3)){
if(b>(length(d1$X3)/2)){
d1$X3[b] = "1"} else {
d1$X3[b] = "2"}}

thr2 = c(brewer.pal(5,"Blues")[3],brewer.pal(5,"Reds")[3],brewer.pal(5,"Greens")[3])
thr1 = c(brewer.pal(5,"Blues")[5],brewer.pal(5,"Reds")[5],brewer.pal(5,"Greens")[5])

brewer_a = c(thr1,thr2,thr1,thr2)
check =c("w_1","All uncertain","TIM>ENV>REC>REIN","TIM>ENV?REC?REIN, TIM>0.5")
g1 <-ggplot(data=d1, aes(x=c(rep(seq(0,12),12)),y = X2*100, group = X1, colour = X1, linetype=X1))+ geom_line(size = 0.75)+theme_bw()+labs(x = "Rank", y = "Probability (%)")+scale_x_continuous(breaks=c(seq(0,12) ))+scale_colour_manual("",values=brewer_a) +scale_linetype_manual("", values=c(1,1,1,1,1,1,4,4,4,4,4,4))+ggtitle(check[num])

g1b <-ggplot(data=d1, aes(x=c(rep(seq(0,12),12)),y = X2*100, group = X1, colour = X1, linetype=X1))+ geom_line(size = 0.75)+theme_bw()+labs(x = "Rank", y = "Probability (%)")+scale_x_continuous(breaks=c(seq(0,12) ))+scale_colour_manual("",values=brewer_a) +scale_linetype_manual("", values=c(1,1,1,1,1,1,4,4,4,4,4,4))+ggtitle(check[num])+ theme(legend.position="none")

for(b in 1:length(d2$X1)){
if(nchar(toString(d2$X1[b]))==1){
c1 = "R "} else {
c1 = "R"}

d2$X1[b] = paste(c1,toString(d2$X1[b]),sep="")
}

mypalette<-brewer.pal(12,"Set3")

h1 <- ggplot(d2, aes(x = X3,Rank, y = X2*100,fill=X1)) + geom_bar(stat='identity',colour="black")+
theme_bw()+labs(x = "Alternative", y = "Probability (%)")+scale_x_continuous(breaks=c(seq(1,12) ))+#scale_colour_manual("",values=brewer_a) 
scale_fill_manual("", values=c(rev(brewer.pal(7,"Greens")[2:7]),brewer.pal(7,"Reds")[2:7]))+ggtitle(substitute(~italic('w'[x]), list(x=num)))+theme(plot.title = element_text(hjust = 0.5))	+guides(fill = guide_legend(reverse=TRUE))

h1b <- ggplot(d2, aes(x = X3,Rank, y = X2*100,fill=X1)) + geom_bar(stat='identity',colour="black")+
theme_bw()+labs(x = "Alternative", y = "Probability (%)")+scale_x_continuous(breaks=c(seq(1,12) ))+#scale_colour_manual("",values=brewer_a) 
scale_fill_manual("", values=c(rev(brewer.pal(7,"Greens")[2:7]),brewer.pal(7,"Reds")[2:7]))+ggtitle(substitute(~italic('w'[x]), list(x=num)))+ theme(legend.position="none")+theme(plot.title = element_text(hjust = 0.5))+guides(fill = guide_legend(reverse=TRUE))
  
assign(paste("f", num, sep=""),g1+scale_y_reverse())
assign(paste("j", num, sep=""),h1+scale_y_reverse())
assign(paste("g", num,REFS[re], sep=""),g1b+scale_y_reverse())
assign(paste("h", num,REFS[re], sep=""),h1b+scale_y_reverse())
 }

setwd(paste(path,"Figures/",sep=""))

jpeg(file = paste("Multi_figs_bar",REFS[re],".jpg",sep=""), height = 4000, width = 4000,res=300)    
multiplot(j1,j3,j2,j4,  cols=2)
dev.off()

}

multiplot(h1_CONS_D,h2_CONS_D,h3_CONS_D,h4_CONS_D,h1_IND_D,h2_IND_D,h3_IND_D,h4_IND_D,cols=4)

